s4u.image
==============

This package implements the data a basic image library. It has three basic
tasks:

1. manage a database of images, with image date stored on the filesystem and
   image metadata stored in a relational database.
2. scale image to a given width or height or weight & height, but without and
   with cropping.
3. store image scales so images never have to be scaled more than use.

.. toctree::
   :maxdepth: 1

   usage
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
